rai\_toolbox.optim.L1FrankWolfe
===============================

.. currentmodule:: rai_toolbox.optim

.. autoclass:: L1FrankWolfe

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~L1FrankWolfe.__init__

   
   